pub struct Parser<'a> { /* private fields */ }Expand description
Create a parser with some source code, then parse it.
Implementations
Sourceimpl<'a> Parser<'a>
impl<'a> Parser<'a>
Sourcepub fn new(allocator: &'a Allocator, source: &'a str, syntax: Syntax) -> Self
pub fn new(allocator: &'a Allocator, source: &'a str, syntax: Syntax) -> Self
Create a parser with the given source code and specified syntax.
If you need to control more options, please use ParserBuilder.
Sourcepub fn recoverable_errors(&self) -> &[Error]
pub fn recoverable_errors(&self) -> &[Error]
Retrieve recoverable errors.