pub struct TemplatePlaceholder {
pub prefix: &'static str,
}Expand description
Configuration for a backtick-delimited template placeholder.
A placeholder has the shape `<prefix><decimal index>` (e.g. with
prefix = "PLACEHOLDER-": `PLACEHOLDER-0`). The opening and closing
backticks are fixed; only prefix is supplied by the downstream consumer, so
oxc-css-parser stays agnostic to its content and only uses it to recognize and index
the token.
Backtick is not valid CSS/SCSS/Sass syntax (it is only Less’s inline-JS
delimiter), so this is intended for SCSS parsing only; see
ParserOptions::template_placeholder.
Fields
prefix: &'static strText after the opening backtick that marks the start of a placeholder,
before its decimal index (e.g. "PLACEHOLDER-").